.. module:: ase.spectrum.doscollection
   :synopsis: Density of states collection objects

=============================
Density of states collections
=============================
*The dosdata and doscollection modules contained in ase.spectrum form*
*a new framework, intended to replace the DOS implementations in*
*ase.dft.dos and ase.dft.pdos.*

This module provides DOSCollection and GridDOSCollection objects that
contain a set of related DOS data objects. This would typically
represent partitioned contributions to a density-of-states, such as
atomic contributions to a vibrational spectrum or orbital
contributions to an electronic spectrum.

More details
------------

.. automodule:: ase.spectrum.doscollection
   :members:
   :noindex:
